ResultUnwrapException class

Thrown by ResultX.getOrThrow when called on an Error.

Implemented types

Constructors

ResultUnwrapException(Failure failure)
Creates an unwrap exception carrying the originating failure.
const

Properties

failure Failure
The failure that the caller chose to escalate to an exception.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited