ResultLoggerInterceptor class
A Dio Interceptor that emits structured, human-readable log output for requests, responses, and errors.
Wire it up by adding the interceptor to the Dio instance you pass to
DioResultHandler:
final dio = Dio()..interceptors.add(ResultLoggerInterceptor());
final api = DioResultHandler(dio);
- Inheritance
-
- Object
- Interceptor
- ResultLoggerInterceptor
Constructors
- ResultLoggerInterceptor({bool logRequest = true, bool logResponse = true, bool logError = true, bool logHeaders = false, bool logBody = true, LogCallback? logger})
- Creates a logger interceptor.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- logBody → bool
-
Whether request / response bodies are included in the log output.
final
- logError → bool
-
Whether errors / non-2xx responses are logged.
final
- logHeaders → bool
-
Whether headers are included in the log output.
final
- logRequest → bool
-
Whether outgoing requests are logged.
final
- logResponse → bool
-
Whether successful responses are logged.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onError(
DioException err, ErrorInterceptorHandler handler) → void -
Called when an exception was occurred during the request.
override
-
onRequest(
RequestOptions options, RequestInterceptorHandler handler) → void -
Called when the request is about to be sent.
override
-
onResponse(
Response response, ResponseInterceptorHandler handler) → void -
Called when the response is about to be resolved.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited